@@ -25,27 +25,29 @@ template<class I>
 matrix<I>::matrix(int nrows, int mcols)
 {
 	int i;
-	while (i++ < nrows)
-		this._rows.push_back(std::vector<I>().reserve(mcols));
-
+	while (i++ < nrows) {
+		std::vector<I> v;
+		v.reserve(mcols);
+		this->_rows.push_back(v);
+	}
 }
 
 template<class I>	
 matrix<I>::matrix(matrix const& s)
 {
-	if (s == *this)
-		return;
+//	if (s == *this)
+//		return;
 
-	this._rows = s._rows;
+	this->_rows = s._rows;
 }
 
 template<class I>	
 matrix<I>& matrix<I>::operator=(matrix const& s)
 {
-	if (s == *this)
-		return *this;
+//	if (s == *this)
+//		return *this;
 
-	this._rows = s._rows;
+	this->_rows = s._rows;
 
 	return *this;
 }
@@ -56,5 +58,14 @@ std::vector<I> matrix<I>::operator[](int index)
 	return _rows[index];
 }
 
+template<class I>
+void matrix<I>::set(I data, int r, int c)
+{
+
+	_rows[r][c] = data;
 
 }
+
+}
+
+template class cola::matrix<double>;
