@@ -28,12 +28,17 @@ template <class I>
 class matrix 
 {
 
-typedef std::vector<I> row;
+////typedef std::vector<I> row;
 
 public:
 	matrix(int nrows, int mcols);
 	matrix(matrix const& s);
 
+	void set(I data, int r, int c);
+
+	int getnrows() { return _rows.size(); }
+	int getncols() { return _rows[0].size(); }
+
 public:
 	std::vector<I> operator[](int index); 
 	matrix& operator=(matrix const& s); 
